Overview — Routes v1.12 documentation

Routes

### Navigation

- index
- modules |
- Routes home |
- Documentation»

Routes is a Python re-implementation of the Rails routes system for mapping URLs to application actions, and conversely to generate URLs. Routes makes it easy to create pretty and concise URLs that are RESTful with little effort.

Routes allows conditional matching based on domain, cookies, HTTP method, or a custom function. Sub-domain support is built in. Routes comes with an extensive unit test suite.

Buzzword Compliance: REST, DRY

## New features

Version 1.12 (2010-02-28)

- Explicit method of calling Mapper.routematch directly
- Submapper improvements for better resource handling
- Various bug fixes

Version 1.11 (2009-09-28)

- Completely new manual
- Add a group of routes under a common URL prefix

Full changelog

## Documentation

Contents for a complete overview Search search the documentation TODO future development plans | General Index all functions, classes, terms Module Index quick access to all documented modules

Download Routes PDF documentation.

## Developers / Source Code

Routes' Mercurial repository can be found at `http://bitbucket.org/bbangert/routes/`.

To check it out:

    hg clone http://www.bitbucket.org/bbangert/routes

### Navigation

- index
- modules |
- Routes home |
- Documentation»